<?php

namespace App\Http\Controllers\Auth;

use App\User;
use App\Gift;
use App\Score;
use Carbon\Carbon;
use Validator;
use App\Http\Controllers\Controller;
use Illuminate\Foundation\Auth\ThrottlesLogins;
use Illuminate\Foundation\Auth\AuthenticatesAndRegistersUsers;
use Illuminate\Contracts\Auth\Guard;
//use Illuminate\Http\Request\Auth;
use App\Http\Requests;
use App\Http\Requests\Auth\LoginRequest;
use App\Http\Requests\Auth\RegisterRequest;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;

class AuthController extends Controller
{

    /**
     * User model instance
     * @var User
     */
    protected $user;

    /**
     * For Guard
     *
     * @var Authenticator
     */
    protected $auth;

    use AuthenticatesAndRegistersUsers, ThrottlesLogins;

    /**
     * Create a new authentication controller instance.
     *
     * @return void
     */
    public function __construct(Guard $auth, User $user)
    {
        $this->user = $user;
        $this->auth = $auth;
        $this->middleware('guest', ['except' => 'getLogout']);
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => 'required|max:255',
            'mobile_number' => 'required|unique:users',
            'department' => 'required|confirmed|min:6',
            //'password' => 'required|confirmed|min:6',
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return User
     */
    protected function create(array $data)
    {

        return User::create([
            'name' => $data['name'],
            'mobile_number' => $data['mobile_number'],
            'department' => $data['mobile_number'],
            //'password' => bcrypt($data['password']),
        ]);
    }

    /* Login get post methods */
    protected function getLogin() {
        return View('users.login');
    }

    protected function postLogin(LoginRequest $request) {
        if (Auth::check())
        {
            // The user is logged in...
            $this->auth->logout();
        }
        if ($this->auth->attempt($request->only('mobile_number', 'password'))) {
          //$user = Auth::user();
          //$user = User::with('scores')->whereUserId(Auth::user()->id)->get();
          //return $user;

          $user = User::find(Auth::id());
          $scores = Score::where('user_id', $user->id)->get();
          $scorecount = count($scores);

          $scoredate = Score::where('user_id', $user->id)->whereDate('created_at', '=', Carbon::today()->toDateString())->count();

          $gifts = Gift::where('user_id', $user->id)->get();
          if ( $scoredate <= 3 )
          {
            return redirect()->route('quizone', compact('scores', 'scorecount', 'gifts'));
          }else {
            $this->auth->logout();
            return redirect('/')->with('alert-warning', 'You have taken the challenge more than three times today. Plese try again tommorow to stand a chance to win.');
            //dd($scoredate);
          }


        }

        return redirect('/')->withErrors([
            'mobile_number' => 'The mobile number is invalid. Please try again.',
        ]);
    }

    /* Register get post methods */
    protected function getRegister() {
        return View('users.register');
    }

    protected function postRegister(RegisterRequest $request) {
      if (Auth::check())
      {
          // The user is logged in...
          $this->auth->logout();
      }
      $user = User::where('mobile_number', '=', Input::get('mobile_number'))->first();
      if ($user === null) {
         // user doesn't exist
         $this->user->name = $request->name;
         $this->user->mobile_number = $request->mobile_number;
         $this->user->department = $request->department;
         $this->user->password = bcrypt('secret');
         $this->user->save();
         $request->session()->flash('alert-success', 'You have successful registered please login to proceed!');
         return redirect('/');
      }else {
        # code...
        return redirect('/');
        $request->session()->flash('alert-danger', 'User not successful added!');
      }

    }

    /**
     * Log the user out of the application.
     *
     * @return Response
     */
    protected function getLogout()
    {
        $this->auth->logout();
        return redirect('/')->with('alert-seccess', 'Succesfully ended your current logged in session ');
    }
}
